<!DOCTYPE html>
<html>
<head>
<title>{% block title %}{{ data["formattedName"] }}{% endblock %}</title>
  <link rel="stylesheet" href="http://netdna.bootstrapcdn.com/bootstrap/3.0.3/css/bootstrap.min.css">
  <link rel="stylesheet" href="http://netdna.bootstrapcdn.com/bootstrap/3.0.3/css/bootstrap-theme.min.css">
  <link rel="stylesheet" href="{{ url_for('static', filename='css/style.css') }}">

  <script type="text/javascript" src="http://code.jquery.com/jquery.min.js"></script>
  <script src="http://netdna.bootstrapcdn.com/bootstrap/3.0.3/js/bootstrap.min.js"></script>

  </head>
  <body data-spy="scroll" data-target="#side-nav">
    <div class="container-fluid">
    <div class=row-fluid">
    <div class="col-md-2">
    <div id="side-nav" >
    <ul class="nav nav-tabs nav-stacked affix-top" data-spy="affix" data-offset-top="125">
    {% block sidebar %}{%endblock %}
    </ul>
    </div></div>
    <div class="col-md-10">
    {% block pages %}<h1>Hello, world!</h1>{% endblock %}
    </div></div>
  </body>
</html>
